@@ -22,8 +22,8 @@
 #include <Python.h>
 #include <glib.h>
 
-#include "pyglib.h"
-
+#include "pygi-python-compat.h"
+#include "pygi-basictype.h"
 #include "pygspawn.h"
 #include "pygi-error.h"
 
@@ -78,7 +78,7 @@ pyg_pid_new(GPid pid)
 #ifdef G_OS_WIN32
     long_val = PyLong_FromVoidPtr (pid);
 #else
-    long_val = PYGLIB_PyLong_FromLong (pid);
+    long_val = pygi_gint_to_py (pid);
 #endif
     return PyObject_CallMethod((PyObject*)&PyGPid_Type, "__new__", "ON",
                                &PyGPid_Type, long_val);
@@ -237,21 +237,21 @@ pyglib_spawn_async(PyObject *object, PyObject *args, PyObject *kwargs)
     if (envp) g_free(envp);
 
     if (standard_input)
-        pystdin = PYGLIB_PyLong_FromLong(*standard_input);
+        pystdin = pygi_gint_to_py(*standard_input);
     else {
         Py_INCREF(Py_None);
         pystdin = Py_None;
     }
 
     if (standard_output)
-        pystdout = PYGLIB_PyLong_FromLong(*standard_output);
+        pystdout = pygi_gint_to_py(*standard_output);
     else {
         Py_INCREF(Py_None);
         pystdout = Py_None;
     }
 
     if (standard_error)
-        pystderr = PYGLIB_PyLong_FromLong(*standard_error);
+        pystderr = pygi_gint_to_py(*standard_error);
     else {
         Py_INCREF(Py_None);
         pystderr = Py_None;
@@ -260,8 +260,11 @@ pyglib_spawn_async(PyObject *object, PyObject *args, PyObject *kwargs)
     return Py_BuildValue("NNNN", pyg_pid_new(child_pid), pystdin, pystdout, pystderr);
 }
 
-void
-pyglib_spawn_register_types(PyObject *d)
+/**
+ * Returns 0 on success, or -1 and sets an exception.
+ */
+int
+pygi_spawn_register_types(PyObject *d)
 {
     PyGPid_Type.tp_base = &PYGLIB_PyLong_Type;
     PyGPid_Type.tp_flags = Py_TPFLAGS_DEFAULT;
@@ -270,4 +273,6 @@ pyglib_spawn_register_types(PyObject *d)
     PyGPid_Type.tp_free = (freefunc)pyg_pid_free;
     PyGPid_Type.tp_new = PYGLIB_PyLong_Type.tp_new;
     PYGLIB_REGISTER_TYPE(d, PyGPid_Type, "Pid");
+
+    return 0;
 }
