@@ -34,12 +34,14 @@ class Test(unittest.TestCase):
     def test_gvalue_converters(self):
         surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, 10, 10)
         context = cairo.Context(surface)
+        matrix = cairo.Matrix()
         objects = {
             'CairoContext': context,
             'CairoSurface': surface,
             'CairoFontFace': context.get_font_face(),
             'CairoScaledFont': context.get_scaled_font(),
             'CairoPattern': context.get_source(),
+            'CairoMatrix': matrix,
         }
         for type_name, cairo_obj in objects.items():
             gtype = GObject.type_from_name(type_name)
@@ -115,6 +117,27 @@ class Test(unittest.TestCase):
         options = cairo.FontOptions()
         Regress.test_cairo_font_options_none_in(options)
 
+    def test_cairo_pattern_full_in(self):
+        pattern = cairo.SolidPattern(1, 1, 1, 1)
+        Regress.test_cairo_pattern_full_in(pattern)
+
+        with pytest.raises(TypeError):
+            Regress.test_cairo_pattern_full_in(object())
+
+    def test_cairo_pattern_none_in(self):
+        pattern = cairo.SolidPattern(1, 1, 1, 1)
+        Regress.test_cairo_pattern_none_in(pattern)
+
+    def test_cairo_pattern_full_return(self):
+        pattern = Regress.test_cairo_pattern_full_return()
+        self.assertTrue(isinstance(pattern, cairo.Pattern))
+        self.assertTrue(isinstance(pattern, cairo.SolidPattern))
+
+    def test_cairo_pattern_none_return(self):
+        pattern = Regress.test_cairo_pattern_none_return()
+        self.assertTrue(isinstance(pattern, cairo.Pattern))
+        self.assertTrue(isinstance(pattern, cairo.SolidPattern))
+
     def test_cairo_region_full_in(self):
         region = cairo.Region()
         Regress.test_cairo_region_full_in(region)
